@@ -5,8 +5,8 @@ from django.utils.translation import ungettext, ugettext_lazy as _
 from django.utils.safestring import mark_safe
 
 from dbtemplates import settings
-from dbtemplates.models import (Template, backend, remove_cached_template,
-        add_template_to_cache)
+from dbtemplates.models import (Template,
+    remove_cached_template, add_template_to_cache)
 
 # Check if django-reversion is installed and use reversions' VersionAdmin
 # as the base admin class if yes
@@ -15,13 +15,15 @@ if settings.USE_REVERSION:
 else:
     from django.contrib.admin import ModelAdmin as TemplateModelAdmin
 
+
 class CodeMirrorTextArea(forms.Textarea):
     """
-    A custom widget for the CodeMirror browser editor to be used with the 
+    A custom widget for the CodeMirror browser editor to be used with the
     content field of the Template model.
     """
     class Media:
-        css = dict(screen=[posixpath.join(settings.MEDIA_PREFIX, 'css/editor.css')])
+        css = dict(screen=[
+            posixpath.join(settings.MEDIA_PREFIX, 'css/editor.css')])
         js = [posixpath.join(settings.MEDIA_PREFIX, 'js/codemirror.js')]
 
     def render(self, name, value, attrs=None):
@@ -51,10 +53,12 @@ else:
 
 if settings.AUTO_POPULATE_CONTENT:
     content_help_text = _("Leaving this empty causes Django to look for a "
-        "template with the given name and populate this field with its content.")
+        "template with the given name and populate this field with its "
+        "content.")
 else:
     content_help_text = ""
 
+
 class TemplateAdminForm(forms.ModelForm):
     """
     Custom AdminForm to make the content textarea wider.
@@ -85,13 +89,9 @@ class TemplateAdmin(TemplateModelAdmin):
     list_display = ('name', 'creation_date', 'last_changed', 'site_list')
     list_filter = ('sites',)
     search_fields = ('name', 'content')
-    if backend:
-        actions = ['invalidate_cache', 'repopulate_cache']
+    actions = ['invalidate_cache', 'repopulate_cache']
 
     def invalidate_cache(self, request, queryset):
-        if not backend:
-            self.message_user(request, ("There is no active cache backend."))
-            return
         for template in queryset:
             remove_cached_template(template)
         message = ungettext(
@@ -99,12 +99,10 @@ class TemplateAdmin(TemplateModelAdmin):
             "Cache of %(count)d templates successfully invalidated.",
             len(queryset))
         self.message_user(request, message % {'count': len(queryset)})
-    invalidate_cache.short_description = _("Invalidate cache of selected templates")
+    invalidate_cache.short_description = _("Invalidate cache of "
+                                           "selected templates")
 
     def repopulate_cache(self, request, queryset):
-        if not backend:
-            self.message_user(request, ("There is no active cache backend."))
-            return
         for template in queryset:
             add_template_to_cache(template)
         message = ungettext(
@@ -112,10 +110,11 @@ class TemplateAdmin(TemplateModelAdmin):
             "Cache successfully repopulated with %(count)d templates.",
             len(queryset))
         self.message_user(request, message % {'count': len(queryset)})
-    repopulate_cache.short_description = _("Repopulate cache with selected templates")
+    repopulate_cache.short_description = _("Repopulate cache with "
+                                           "selected templates")
 
     def site_list(self, template):
-          return ", ".join([site.name for site in template.sites.all()])
+        return ", ".join([site.name for site in template.sites.all()])
     site_list.short_description = _('sites')
 
 admin.site.register(Template, TemplateAdmin)
